@@ -461,7 +461,7 @@ void ScanViewer::slotScan(const TQStringList & filepattern, int mode, bool recur
         else {
             int choice = KMessageBox::warningYesNoCancel(
                 this,
-                i18n("The ClamAV daemon does not seem to be running on this system. Do you really want to continue with this scan or would you like to launch a standalone scan instead?'"),
+                i18n("The ClamAV daemon does not seem to be running on this system. Do you really want to continue with this scan or would you like to launch a standalone scan instead?"),
                 i18n("Clamd not running"),
                 i18n("Continue this scan"),
                 i18n("Launch standalone scan"),
